@@ -7,7 +7,7 @@ Autor: zmf96
 Email: zmf96@qq.com
 Date: 2022-02-21 08:46:14
 LastEditors: zmf96
-LastEditTime: 2022-02-22 03:48:54
+LastEditTime: 2022-03-29 23:57:50
 FilePath: /subdomain/subdomain.py
 Description: 
 '''
@@ -16,11 +16,10 @@ from loguru import logger
 import sys
 import asyncio
 import aiodns
-import argparse
 import IPy
 import random
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 BASEDIR = os.path.dirname(os.path.abspath(__file__))
 
@@ -185,34 +184,3 @@ class SubDomain:
             self.loop.run_until_complete(self.start_brute())
         except Exception as e:
             logger.warning(e)
-        finally:
-            # self.loop.close()
-            pass
-
-
-def main():
-    logger.debug("subdomain  version 0.1")
-    parser = argparse.ArgumentParser(description='使用aiodns爆破子域名')
-    parser.add_argument("-v", "--version",
-                        action='version', version=__version__)
-    parser.add_argument("-f", "--file", type=str,
-                        help='指定字典文件', default='default.txt')
-    parser.add_argument("-d", "--domain", type=str,
-                        help='目标域名', required=True)
-    parser.add_argument("-s", "--deep", type=int, help='域名深度,默认 1', default=1)
-    args = parser.parse_args()
-    params = {}
-    if args.domain is None:
-        logger.error(
-            "Please input domain  such as python subdns.py -u baidu.com")
-        sys.exit()
-    params['domain'] = args.domain
-    params['deep'] = args.deep
-    params['dictname'] = args.file
-    sd = SubDomain(paras=params)
-    sd.run()
-    print(sd.results)
-    sd.loop.close()
-
-if __name__ == '__main__':
-    main()
